<?php

/**
 * @file
 *
 * Provides browser theme settings administrative interface.
 * @ingroup browser_theme
 */

/**
 * Form builder for browser theme settings configuration.
 *
 * @ingroup forms
 */
function browser_theme_configuration() {
  global $_browser_theme;
  $form = array();
  if (!$_browser_theme->selected) {
    return $form;
  }
  $form = array(
    '#theme'              => 'browser_theme_configuration',
    '#tree'               => TRUE,
    '#empty_text'         => $_browser_theme->empty,
  );
  
  $form['block'] = array(
    '#type'               => 'checkbox',
    '#title'              => t('Block Template Suggestions'),
    '#description'        => t('<span class="icon help"></span><div class="tooltip"><div>'
                             . '<h2>Block Template Suggestions</h2><br />'
                             . 'By enabling this setting, Browser Theme Settings will automatically prepend all previously suggested template files with the representation of the requesting browser\'s information. This also includes any template suggestions other modules or themes might suggest.<br /><br />Browser Theme Settings will also resort the order of the suggestions and look for the longest template name first.<br /><br/>'
                             . 'Suggestion Order:'
                             . '<ol><li><strong>browser-major-minor-block.tpl.php</strong></li><li><strong>browser-major-block.tpl.php</strong></li><li><strong>browser-block.tpl.php</strong></li><li><strong>block.tpl.php</strong></li></ol>'
                             . 'Example using this browser\'s information:'
                             . '<ol><li><em>' . $_browser_theme->browser . '-' . $_browser_theme->major . '-' . $_browser_theme->minor . '-block.tpl.php</em></li><li><em>' . $_browser_theme->browser . '-' . $_browser_theme->major . '-block.tpl.php</em></li><li><em>' . $_browser_theme->browser . '-block.tpl.php</em></li><li><em>block.tpl.php</em></li></ol>'
                             . '</div></div>'),
    '#default_value'      => $_browser_theme->selected['block'],
  );
  $form['node'] = array(
    '#type'               => 'checkbox',
    '#title'              => t('Node Template Suggestions'),
    '#description'        => t('<span class="icon help"></span><div class="tooltip"><div>'
                             . '<h2>Node Template Suggestions</h2><br />'
                             . 'By enabling this setting, Browser Theme Settings will automatically prepend all previously suggested template files with the representation of the requesting browser\'s information. This also includes any template suggestions other modules or themes might suggest.<br /><br />Browser Theme Settings will also resort the order of the suggestions and look for the longest template name first.<br /><br/>'
                             . 'Suggestion Order:'
                             . '<ol><li><strong>browser-major-minor-node.tpl.php</strong></li><li><strong>browser-major-node.tpl.php</strong></li><li><strong>browser-node.tpl.php</strong></li><li><strong>node.tpl.php</strong></li></ol>'
                             . 'Example using this browser\'s information:'
                             . '<ol><li><em>' . $_browser_theme->browser . '-' . $_browser_theme->major . '-' . $_browser_theme->minor . '-node.tpl.php</em></li><li><em>' . $_browser_theme->browser . '-' . $_browser_theme->major . '-node.tpl.php</em></li><li><em>' . $_browser_theme->browser . '-node.tpl.php</em></li><li><em>node.tpl.php</em></li></ol>'
                             . '</div></div>'),
    '#default_value'      => $_browser_theme->selected['node'],
  );
  $form['page'] = array(
    '#type'               => 'checkbox',
    '#title'              => t('Page Template Suggestions'),
    '#description'        => t('<span class="icon help"></span><div class="tooltip"><div>'
                             . '<h2>Page Template Suggestions</h2><br />'
                             . 'By enabling this setting, Browser Theme Settings will automatically prepend all previously suggested template files with the representation of the requesting browser\'s information. This also includes any template suggestions other modules or themes might suggest.<br /><br />Browser Theme Settings will also resort the order of the suggestions and look for the longest template name first.<br /><br/>'
                             . 'Suggestion Order:'
                             . '<ol><li><strong>browser-major-minor-page.tpl.php</strong></li><li><strong>browser-major-page.tpl.php</strong></li><li><strong>browser-page.tpl.php</strong></li><li><strong>page.tpl.php</strong></li></ol>'
                             . 'Example using this browser\'s information:'
                             . '<ol><li><em>' . $_browser_theme->browser . '-' . $_browser_theme->major . '-' . $_browser_theme->minor . '-page.tpl.php</em></li><li><em>' . $_browser_theme->browser . '-' . $_browser_theme->major . '-page.tpl.php</em></li><li><em>' . $_browser_theme->browser . '-page.tpl.php</em></li><li><em>page.tpl.php</em></li></ol>'
                             . '</div></div>'),
    '#default_value'      => $_browser_theme->selected['page'],
  );

  
  foreach ($_browser_theme->selected['css'] as $key => $file) {
    $form['css']['files'][$key]['weight'] = array(
      '#type'               => 'weight',
      '#delta'              => count($_browser_theme->selected['css']),
      '#default_value'      => $key,
      '#attributes'         => array('class' => 'weight'),
    );
    $form['css']['files'][$key]['file'] = array(
      '#type'               => 'textfield',
      '#field_prefix'       => ($_browser_theme->selected['path'] ? '/'. $_browser_theme->selected['path'] . '/' : ''),
      '#value'              => $_browser_theme->selected['css'][$key]['file'],
      '#attributes'         => array('class' => 'file'),
    );
    $form['css']['files'][$key]['preprocess'] = array(
      '#type'               => 'checkbox',
      '#default_value'      => $_browser_theme->selected['css'][$key]['preprocess'],
      '#attributes'         => array('class' => 'preprocess'),
    );
    $form['css']['files'][$key]['maintenance'] = array(
      '#type'               => 'checkbox',
      '#default_value'      => $_browser_theme->selected['css'][$key]['maintenance'],
      '#attributes'         => array('class' => 'maintenance'),
    );
  }
  
  
  foreach ($_browser_theme->selected['js'] as $key => $file) {
    $form['js']['files'][$key]['weight'] = array(
      '#type'               => 'weight',
      '#delta'              => count($_browser_theme->selected['js']),
      '#default_value'      => $key,
      '#attributes'         => array('class' => 'weight'),
    );
    $form['js']['files'][$key]['file'] = array(
      '#type'               => 'textfield',
      '#field_prefix'       => ($_browser_theme->selected['path'] ? '/'. $_browser_theme->selected['path'] . '/' : ''),
      '#value'              => $_browser_theme->selected['js'][$key]['file'],
      '#attributes'         => array('class' => 'file'),
    );
    $form['js']['files'][$key]['cache'] = array(
      '#type'               => 'checkbox',
      '#default_value'      => $_browser_theme->selected['js'][$key]['cache'],
      '#attributes'         => array('class' => 'cache'),
    );
    $form['js']['files'][$key]['preprocess'] = array(
      '#type'               => 'checkbox',
      '#default_value'      => $_browser_theme->selected['js'][$key]['preprocess'],
      '#attributes'         => array('class' => 'preprocess'),
    );
    $form['js']['files'][$key]['maintenance'] = array(
      '#type'               => 'checkbox',
      '#default_value'      => $_browser_theme->selected['js'][$key]['maintenance'],
      '#attributes'         => array('class' => 'maintenance'),
    );
  }
  return $form;
}
