<?php

/**
 * @file
 *
 * Core class, functions and variables for browser_theme.
 * @ingroup browser_theme
 */

// Load current browser variables
if (!function_exists('browscap_get_browser') && function_exists('drupal_load')) {
  drupal_load('module', 'browscap');
}

// Check to see if this argument is set as not to throw an error
if (isset($_SERVER['HTTP_USER_AGENT'])) {
  $browscap = browscap_get_browser($_SERVER['HTTP_USER_AGENT']);
  $_browser_theme->browser = strtolower($browscap['browser']);
  $_browser_theme->major = $browscap['majorver'];
  $_browser_theme->minor = $browscap['minorver'];
}
else {
  $_browser_theme->browser = 'generic';
  $_browser_theme->major = 0;
  $_browser_theme->minor = 0;
}

//Maintenance Mode
$_browser_theme->maintenance = FALSE;

// Domain Access integration
$_browser_theme->domain['id'] = 0;
if (module_exists('domain')) {
  global $_domain;
  $_browser_theme->domain['id'] = (int) $_domain['domain_id'];
}

// Additional Variables
$_browser_theme->empty = 'No file suggestions. You can add a file by clicking the green plus icon above.';

function browser_theme_load_settings($theme = NULL, $did = NULL) {
  global $_browser_theme;
  if (variable_get('browscap_version', FALSE) == FALSE && function_exists('_browscap_import') && function_exists('drupal_http_request')) {
    _browscap_import();
  }
  if ($theme == '%current%') {
    $theme = $_browser_theme->theme['name'];
  }
  if (is_null($did) || empty($did)) {
    $did = $_browser_theme->domain['id'];
  }
  $defaults = array(
    'name'   => NULL,
    'path'   => NULL,
    'block'  => 1,
    'node'   => 1,
    'page'   => 1,
    'css'    => array(),
    'js'     => array(),
  );
  // Load the site's default global browser theme settings if it exists. If it does not exist, use Browser Theme's default settings instead.
  $global = array_merge($defaults, variable_get('browser_theme_settings', $defaults));
  // Load a specific theme's browser theme settings if it exists. If it does not exist, use the existing global variables instead.
  $settings = $global;
  if ($theme) {
    $settings = array_merge($global, variable_get('browser_theme_settings_' . $theme, $global));
    // Load domain specific theme settings
    if (!empty($did) && $did != 0) {
      $settings = array_merge($settings, variable_get('browser_theme_settings_' . $theme . '_domain_' . (string) $did, $settings));
    }
    $settings['name'] = $theme;
    if (function_exists('drupal_get_path')) {
      $settings['path'] = drupal_get_path('theme', $theme);      
    }
  }
  return $settings;
}

function browser_theme_save_settings($value = NULL) {
  global $conf;
  if ($value) {
    if (!$value['did']) {
      $value['did'] = 0;
    }
    $theme = $value['name'];
    if ($theme) {
      if ($value['did'] != 0) {
        $theme = $theme . '_domain_' . $value['did'];
      }
      $name = 'browser_theme_settings_' . $theme;
    }
    else {
      $name = 'browser_theme_settings';
    }    
    $serialized_value = serialize($value);
    db_query("UPDATE {variable} SET value = '%s' WHERE name = '%s'", $serialized_value, $name);
    if (!db_affected_rows()) {
      @db_query("INSERT INTO {variable} (name, value) VALUES ('%s', '%s')", $name, $serialized_value);
    }
    cache_clear_all('variables', 'cache', TRUE);
    $conf[$name] = $value;
  }
}

function _browser_theme_file_suggestions($repository = array()) {
  global $_browser_theme, $theme;
  $files = array();
  if (!empty($repository)) {
    foreach ($repository as $key => $file) {
      // Determine if page is in maintenance mode and if file should be loaded
      if ($_browser_theme->maintenance && !(bool)$file['maintenance']) {
        continue;
      }
      $info = pathinfo($file['file']);
      $filename = $info['basename'];
      $filepath = $info['dirname'] == '.' ? '' : $info['dirname'] . '/';
      $theme_path = $_browser_theme->theme['path'] ? $_browser_theme->theme['path'] : @drupal_get_path('theme', $_browser_theme->theme['name']);
      $suggestions = array();
      $suggestions[] = $theme_path . '/' . $filepath . $_browser_theme->browser . '-' . $_browser_theme->major . '-' . $_browser_theme->minor . '-' . $filename;
      $suggestions[] = $theme_path . '/' . $filepath . $_browser_theme->browser . '-' . $_browser_theme->major . '-' . $filename;
      $suggestions[] = $theme_path . '/' . $filepath . $_browser_theme->browser . '-' . $filename;
      $suggestions[] = $theme_path . '/' . $filepath . $filename;
      foreach ($suggestions as $key => $path) {
        // Only use the first file that exists, a maintenance version will only load if the normal file exists.
        if (file_exists($path)) {
          // Determine if page is in maintenance mode and if a special maintenance version of the file exists
          if ($_browser_theme->maintenance && (bool)$file['maintenance']) {
            $info = pathinfo($path);
            $maintenance_path = $info['dirname'] . '/' . 'maintenance-' . $info['basename'];
            if (file_exists($maintenance_path)) {
              $path = $maintenance_path;
            }
          }
          $cache = array();
          $preprocess = array();
          if (isset($file['cache'])) {
            $cache = array('cache' => (bool) $file['cache']);
          }
          if (isset($file['preprocess'])) {
            $preprocess = array('preprocess' => (bool) $file['preprocess']);
          }
          $files[] = array_merge(array('path' => $path), $cache, $preprocess);
          break;
        }
      }
    }
  }
  return $files;
}

function _browser_theme_add_css() {
  global $_browser_theme;
  $files = _browser_theme_file_suggestions($_browser_theme->theme['css']);
  foreach ($files as $key => $file) {
    drupal_add_css($file['path'], $type = 'theme', 'all', $file['preprocess']);
  }
  return drupal_add_css();
}

function _browser_theme_add_js() {
  global $_browser_theme;
  $files = _browser_theme_file_suggestions($_browser_theme->theme['js']);
  foreach ($files as $key => $file) {
    drupal_add_js($file['path'], 'theme', 'header', FALSE, $file['cache'], (!$file['cache'] ? FALSE : $file['preprocess']));
  }
  return drupal_add_js();
}

function _browser_theme_ajax_save() {
  $settings = array();
  $settings['did'] = (int) $_POST['did'];
  $settings['name'] = $_POST['name'];
  $settings['path'] = $_POST['path'];
  $settings['block'] = (int)$_POST['block'];
  $settings['node'] = (int)$_POST['node'];
  $settings['page'] = (int)$_POST['page'];
  $css_count = (int)($_POST['css'] - 1);
  $css_file = (array) json_decode($_POST['cssFile'], TRUE);
  $css_preprocess = (array) json_decode($_POST['cssPreprocess'], TRUE);
  $css_maintenance = (array) json_decode($_POST['cssMaintenance'], TRUE);
  $js_count = (int)($_POST['js'] - 1);
  $js_file = (array) json_decode($_POST['jsFile'], TRUE);
  $js_cache = (array) json_decode($_POST['jsCache'], TRUE);
  $js_preprocess = (array) json_decode($_POST['jsPreprocess'], TRUE);
  $js_maintenance = (array) json_decode($_POST['jsMaintenance'], TRUE);
  $settings['css'] = array();
  $settings['js'] = array();
  for ($i = 0; $i <= $css_count; $i++) {
    $settings['css'][$i]['file'] = $css_file[$i];
    $settings['css'][$i]['preprocess'] = $css_preprocess[$i];
    $settings['css'][$i]['maintenance'] = $css_maintenance[$i];
  }
  for ($i = 0; $i <= $js_count; $i++) {
    $settings['js'][$i]['file'] = $js_file[$i];
    $settings['js'][$i]['cache'] = $js_cache[$i];
    $settings['js'][$i]['preprocess'] = $js_preprocess[$i];
    $settings['js'][$i]['maintenance'] = $js_maintenance[$i];
  }
  browser_theme_save_settings($settings);
  exit();
}
