<?php

/**
 * @file
 *
 * Default theme implementation for administration form.
 * @ingroup browser_theme
 */

/**
 * Formats administration page callback.
 *
 * @ingroup themeable
 */
function theme_browser_theme_configuration($form) {
  global $_browser_theme;
  $output = '<div id="browser_theme">';
  if ($_browser_theme->message) {
    $output .= '<div class="messages warning">' . $_browser_theme->message . '</div>';
  }
  
  $output .= drupal_render($form['block']);
  $output .= drupal_render($form['node']);
  $output .= drupal_render($form['page']);
  
  // CSS Table
  drupal_add_tabledrag('cssTable', 'order', 'sibling', 'weight');
  $header = array(
    array('data' => '<span class="form-item"><label for="cssTable">CSS File Suggestions <span class="description">'
                  . '<span class="icon help"></span><div class="tooltip"><div>'
                  . '<h2>CSS File Suggestions</h2><br />'
                  . 'Typically your theme supplies the CSS files in the .info file located within your theme\'s folder. Simply remove your CSS files from this theme\'s .info file and save them here. Browser Theme Settings will automatically prepend all CSS files with the requesting browser\'s information to create CSS file suggestions.<br /><br />Browser Theme Settings will try loading the first CSS suggestion. If it cannot find and existing file for that particular suggestion it will move on to the next and so forth until the original CSS file is loaded by default. Please also note that the path of the CSS file is relative to the theme. In the global settings, the active theme will become the path.<br /><br/>'
                  . 'Suggestion Order:'
                  . '<ol><li><strong>browser-major-minor-style.css</strong></li><li><strong>browser-major-style.css</strong></li><li><strong>browser-style.css</strong></li><li><strong>style.css</strong></li></ol>'
                  . 'Example using this browser\'s information:'
                  . '<ol><li><em>' . $_browser_theme->browser . '-' . $_browser_theme->major . '-' . $_browser_theme->minor . '-style.css</em></li><li><em>' . $_browser_theme->browser . '-' . $_browser_theme->major . '-style.css</em></li><li><em>' . $_browser_theme->browser . '-style.css</em></li><li><em>style.css</em></li></ol>'
                  . '</div></div>'
                  . '</span></label></span>'),
    array('data' => t('Preprocess'), 'style' => 'text-align: center', 'width' => '100'),
    array('data' => t('Maintenance'), 'style' => 'text-align: center', 'width' => '100'),
    array('data' => t('Weight')),
    array('data' => '<span class="css-files icon add" title="Add File"></span>', 'class' => 'action'),
  );
  $rows = array();
  $css = &$form['css']['files'];
  foreach (element_children($css) as $key) {
    $row = array();
    $row[] = array('data' => drupal_render($css[$key]['file']), 'class' => 'file');
    $row[] = array('data' => drupal_render($css[$key]['preprocess']), 'width' => '100', 'align' => 'center');
    $row[] = array('data' => drupal_render($css[$key]['maintenance']), 'width' => '100', 'align' => 'center');
    $row[] = drupal_render($css[$key]['weight']);
    $row[] = array('data' => '<span class="css-files icon delete" title="Remove File"></span>', 'class' => 'action');
    $rows[] = array('data' => $row, 'class' => 'draggable');
  }
  if (empty($css)) {
    $row = array();
    $row[] = array('data' => $form['#empty_text'], 'class' => 'file');
    $row[] = array('data' => '<span></span>', 'width' => '100', 'align' => 'center');
    $row[] = array('data' => '<span></span>', 'width' => '100', 'align' => 'center');
    $row[] = array('data' => '<span class="weight"></span>');
    $row[] = array('data' => '<span></span>', 'class' => 'action');
    $rows[] = array('data' => $row, 'class' => 'empty');
  }
  $output .= theme('table', $header, $rows, array('id' => 'cssTable'));
  
  
  // JS Table
  drupal_add_tabledrag('jsTable', 'order', 'sibling', 'weight');
  $header = array(
    array('data' => '<span class="form-item"><label for="jsTable">JavaScript File Suggestions <span class="description">'
                  . '<span class="icon help"></span><div class="tooltip"><div>'
                  . '<h2>JavaScript File Suggestions</h2><br />'
                  . 'Typically your theme supplies the JS files in the .info file located within your theme\'s folder. Simply remove your JS files from this theme\'s .info file and save them here. Browser Theme Settings will automatically prepend all JS files with the requesting browser\'s information to create JS file suggestions.<br /><br />Browser Theme Settings will try loading the first JS suggestion. If it cannot find and existing file for that particular suggestion it will move on to the next and so forth until the original JS file is loaded by default. Please also note that the path of the JS file is relative to the theme. In the global settings, the active theme will become the path.<br /><br/>'
                  . 'Suggestion Order:'
                  . '<ol><li><strong>browser-major-minor-script.js</strong></li><li><strong>browser-major-script.js</strong></li><li><strong>browser-script.js</strong></li><li><strong>script.js</strong></li></ol>'
                  . 'Example using this browser\'s information:'
                  . '<ol><li><em>' . $_browser_theme->browser . '-' . $_browser_theme->major . '-' . $_browser_theme->minor . '-script.js</em></li><li><em>' . $_browser_theme->browser . '-' . $_browser_theme->major . '-script.js</em></li><li><em>' . $_browser_theme->browser . '-script.js</em></li><li><em>script.js</em></li></ol>'
                  . '</div></div>'
                  . '</span></label></span>'),
    array('data' => t('Cache'), 'style' => 'text-align: center', 'width' => '100'),
    array('data' => t('Preprocess'), 'style' => 'text-align: center', 'width' => '100'),
    array('data' => t('Maintenance'), 'style' => 'text-align: center', 'width' => '100'),
    array('data' => t('Weight')),
    array('data' => '<span class="css-files icon add" title="Add File"></span>', 'class' => 'action'),
  );
  $rows = array();
  $js = &$form['js']['files'];
  foreach (element_children($js) as $key) {
    $row = array();
    $row[] = array('data' => drupal_render($js[$key]['file']), 'class' => 'file');
    $row[] = array('data' => drupal_render($js[$key]['cache']), 'width' => '100', 'align' => 'center');
    $row[] = array('data' => drupal_render($js[$key]['preprocess']), 'width' => '100', 'align' => 'center');
    $row[] = array('data' => drupal_render($js[$key]['maintenance']), 'width' => '100', 'align' => 'center');
    $row[] = drupal_render($js[$key]['weight']);
    $row[] = array('data' => '<span class="js-files icon delete" title="Remove File"></span>', 'class' => 'action');
    $rows[] = array('data' => $row, 'class' => 'draggable');
  }
  if (empty($js)) {
    $row = array();
    $row[] = array('data' => $form['#empty_text'], 'class' => 'file');
    $row[] = array('data' => '<span></span>', 'width' => '100', 'align' => 'center');
    $row[] = array('data' => '<span></span>', 'width' => '100', 'align' => 'center');
    $row[] = array('data' => '<span></span>', 'width' => '100', 'align' => 'center');
    $row[] = array('data' => '<span class="weight"></span>');
    $row[] = array('data' => '<span></span>', 'class' => 'action');
    $rows[] = array('data' => $row, 'class' => 'empty');
  }
  $output .= theme('table', $header, $rows, array('id' => 'jsTable'));
  $output .= '</div>';
  return $output;
}
